# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheActivityObsDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avalanche_activity_obs_id': 'int',
        'aspect': 'int',
        'heigth_start_zone': 'int',
        'dt_avalanche_time': 'datetime',
        'destructive_size_tid': 'int',
        'estimated_num_tid': 'int',
        'avalanche_tid': 'int',
        'avalanche_trigger_tid': 'int',
        'terrain_start_zone_tid': 'int',
        'snow_line': 'int',
        'usage_flag_tid': 'int',
        'comment': 'str'
    }

    attribute_map = {
        'avalanche_activity_obs_id': 'AvalancheActivityObsID',
        'aspect': 'Aspect',
        'heigth_start_zone': 'HeigthStartZone',
        'dt_avalanche_time': 'DtAvalancheTime',
        'destructive_size_tid': 'DestructiveSizeTID',
        'estimated_num_tid': 'EstimatedNumTID',
        'avalanche_tid': 'AvalancheTID',
        'avalanche_trigger_tid': 'AvalancheTriggerTID',
        'terrain_start_zone_tid': 'TerrainStartZoneTID',
        'snow_line': 'SnowLine',
        'usage_flag_tid': 'UsageFlagTID',
        'comment': 'Comment'
    }

    def __init__(self, avalanche_activity_obs_id=None, aspect=None, heigth_start_zone=None, dt_avalanche_time=None, destructive_size_tid=None, estimated_num_tid=None, avalanche_tid=None, avalanche_trigger_tid=None, terrain_start_zone_tid=None, snow_line=None, usage_flag_tid=None, comment=None):  # noqa: E501
        """AvalancheActivityObsDto - a model defined in Swagger"""  # noqa: E501
        self._avalanche_activity_obs_id = None
        self._aspect = None
        self._heigth_start_zone = None
        self._dt_avalanche_time = None
        self._destructive_size_tid = None
        self._estimated_num_tid = None
        self._avalanche_tid = None
        self._avalanche_trigger_tid = None
        self._terrain_start_zone_tid = None
        self._snow_line = None
        self._usage_flag_tid = None
        self._comment = None
        self.discriminator = None
        self.avalanche_activity_obs_id = avalanche_activity_obs_id
        self.aspect = aspect
        self.heigth_start_zone = heigth_start_zone
        self.dt_avalanche_time = dt_avalanche_time
        if destructive_size_tid is not None:
            self.destructive_size_tid = destructive_size_tid
        if estimated_num_tid is not None:
            self.estimated_num_tid = estimated_num_tid
        if avalanche_tid is not None:
            self.avalanche_tid = avalanche_tid
        if avalanche_trigger_tid is not None:
            self.avalanche_trigger_tid = avalanche_trigger_tid
        if terrain_start_zone_tid is not None:
            self.terrain_start_zone_tid = terrain_start_zone_tid
        if snow_line is not None:
            self.snow_line = snow_line
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if comment is not None:
            self.comment = comment

    @property
    def avalanche_activity_obs_id(self):
        """Gets the avalanche_activity_obs_id of this AvalancheActivityObsDto.  # noqa: E501

        Unik id på denne tabellen da flere er mulig pr RegID.  # noqa: E501

        :return: The avalanche_activity_obs_id of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_activity_obs_id

    @avalanche_activity_obs_id.setter
    def avalanche_activity_obs_id(self, avalanche_activity_obs_id):
        """Sets the avalanche_activity_obs_id of this AvalancheActivityObsDto.

        Unik id på denne tabellen da flere er mulig pr RegID.  # noqa: E501

        :param avalanche_activity_obs_id: The avalanche_activity_obs_id of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """
        if avalanche_activity_obs_id is None:
            raise ValueError("Invalid value for `avalanche_activity_obs_id`, must not be `None`")  # noqa: E501

        self._avalanche_activity_obs_id = avalanche_activity_obs_id

    @property
    def aspect(self):
        """Gets the aspect of this AvalancheActivityObsDto.  # noqa: E501

        Hvilken side av fjellene har skredene gått? Gis i grader slik gitt på kompass. 0 er nord og 90 er øst osv.  # noqa: E501

        :return: The aspect of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._aspect

    @aspect.setter
    def aspect(self, aspect):
        """Sets the aspect of this AvalancheActivityObsDto.

        Hvilken side av fjellene har skredene gått? Gis i grader slik gitt på kompass. 0 er nord og 90 er øst osv.  # noqa: E501

        :param aspect: The aspect of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """
        if aspect is None:
            raise ValueError("Invalid value for `aspect`, must not be `None`")  # noqa: E501

        self._aspect = aspect

    @property
    def heigth_start_zone(self):
        """Gets the heigth_start_zone of this AvalancheActivityObsDto.  # noqa: E501

        Meter over havet på løsneområdet.  # noqa: E501

        :return: The heigth_start_zone of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._heigth_start_zone

    @heigth_start_zone.setter
    def heigth_start_zone(self, heigth_start_zone):
        """Sets the heigth_start_zone of this AvalancheActivityObsDto.

        Meter over havet på løsneområdet.  # noqa: E501

        :param heigth_start_zone: The heigth_start_zone of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """
        if heigth_start_zone is None:
            raise ValueError("Invalid value for `heigth_start_zone`, must not be `None`")  # noqa: E501

        self._heigth_start_zone = heigth_start_zone

    @property
    def dt_avalanche_time(self):
        """Gets the dt_avalanche_time of this AvalancheActivityObsDto.  # noqa: E501

        Når gikk skredene? Her bruker vi feltet som en ca. tid og brukerene oppfordres til å anta best mulig.  # noqa: E501

        :return: The dt_avalanche_time of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_avalanche_time

    @dt_avalanche_time.setter
    def dt_avalanche_time(self, dt_avalanche_time):
        """Sets the dt_avalanche_time of this AvalancheActivityObsDto.

        Når gikk skredene? Her bruker vi feltet som en ca. tid og brukerene oppfordres til å anta best mulig.  # noqa: E501

        :param dt_avalanche_time: The dt_avalanche_time of this AvalancheActivityObsDto.  # noqa: E501
        :type: datetime
        """
        if dt_avalanche_time is None:
            raise ValueError("Invalid value for `dt_avalanche_time`, must not be `None`")  # noqa: E501

        self._dt_avalanche_time = dt_avalanche_time

    @property
    def destructive_size_tid(self):
        """Gets the destructive_size_tid of this AvalancheActivityObsDto.  # noqa: E501

        Hvor store er skredene?. The DestructiveSizeKD unique identifier  # noqa: E501

        :return: The destructive_size_tid of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._destructive_size_tid

    @destructive_size_tid.setter
    def destructive_size_tid(self, destructive_size_tid):
        """Sets the destructive_size_tid of this AvalancheActivityObsDto.

        Hvor store er skredene?. The DestructiveSizeKD unique identifier  # noqa: E501

        :param destructive_size_tid: The destructive_size_tid of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """

        self._destructive_size_tid = destructive_size_tid

    @property
    def estimated_num_tid(self):
        """Gets the estimated_num_tid of this AvalancheActivityObsDto.  # noqa: E501

        Hvor mange skred er gått? The EstimatedNumKD unique identifier  # noqa: E501

        :return: The estimated_num_tid of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._estimated_num_tid

    @estimated_num_tid.setter
    def estimated_num_tid(self, estimated_num_tid):
        """Sets the estimated_num_tid of this AvalancheActivityObsDto.

        Hvor mange skred er gått? The EstimatedNumKD unique identifier  # noqa: E501

        :param estimated_num_tid: The estimated_num_tid of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """

        self._estimated_num_tid = estimated_num_tid

    @property
    def avalanche_tid(self):
        """Gets the avalanche_tid of this AvalancheActivityObsDto.  # noqa: E501

        Typen skred som er gått. The AvalancheKD unique identifier  # noqa: E501

        :return: The avalanche_tid of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_tid

    @avalanche_tid.setter
    def avalanche_tid(self, avalanche_tid):
        """Sets the avalanche_tid of this AvalancheActivityObsDto.

        Typen skred som er gått. The AvalancheKD unique identifier  # noqa: E501

        :param avalanche_tid: The avalanche_tid of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """

        self._avalanche_tid = avalanche_tid

    @property
    def avalanche_trigger_tid(self):
        """Gets the avalanche_trigger_tid of this AvalancheActivityObsDto.  # noqa: E501

        Hva utløste skredet? Det er ofte beskrevet som det svake laget i snødekket. The AvalancheTriggerKD unique identifier  # noqa: E501

        :return: The avalanche_trigger_tid of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_trigger_tid

    @avalanche_trigger_tid.setter
    def avalanche_trigger_tid(self, avalanche_trigger_tid):
        """Sets the avalanche_trigger_tid of this AvalancheActivityObsDto.

        Hva utløste skredet? Det er ofte beskrevet som det svake laget i snødekket. The AvalancheTriggerKD unique identifier  # noqa: E501

        :param avalanche_trigger_tid: The avalanche_trigger_tid of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """

        self._avalanche_trigger_tid = avalanche_trigger_tid

    @property
    def terrain_start_zone_tid(self):
        """Gets the terrain_start_zone_tid of this AvalancheActivityObsDto.  # noqa: E501

        Hva slags terrengtype var det i løsneområdet. The TerrainStartZoneKD unique identifier  # noqa: E501

        :return: The terrain_start_zone_tid of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._terrain_start_zone_tid

    @terrain_start_zone_tid.setter
    def terrain_start_zone_tid(self, terrain_start_zone_tid):
        """Sets the terrain_start_zone_tid of this AvalancheActivityObsDto.

        Hva slags terrengtype var det i løsneområdet. The TerrainStartZoneKD unique identifier  # noqa: E501

        :param terrain_start_zone_tid: The terrain_start_zone_tid of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """

        self._terrain_start_zone_tid = terrain_start_zone_tid

    @property
    def snow_line(self):
        """Gets the snow_line of this AvalancheActivityObsDto.  # noqa: E501

        Hvor går snøgrensa i området?  # noqa: E501

        :return: The snow_line of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._snow_line

    @snow_line.setter
    def snow_line(self, snow_line):
        """Sets the snow_line of this AvalancheActivityObsDto.

        Hvor går snøgrensa i området?  # noqa: E501

        :param snow_line: The snow_line of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """

        self._snow_line = snow_line

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this AvalancheActivityObsDto.  # noqa: E501

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm.  # noqa: E501

        :return: The usage_flag_tid of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this AvalancheActivityObsDto.

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm.  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this AvalancheActivityObsDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def comment(self):
        """Gets the comment of this AvalancheActivityObsDto.  # noqa: E501

        Kommentarfelt for å skrive utfyllende tekst om observasjonen.  # noqa: E501

        :return: The comment of this AvalancheActivityObsDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheActivityObsDto.

        Kommentarfelt for å skrive utfyllende tekst om observasjonen.  # noqa: E501

        :param comment: The comment of this AvalancheActivityObsDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheActivityObsDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheActivityObsDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheActivityObs2ViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'estimated_num_tid': 'int',
        'estimated_num_name': 'str',
        'dt_start': 'datetime',
        'dt_end': 'datetime',
        'dt_off_start': 'datetime',
        'dt_off_end': 'datetime',
        'valid_exposition': 'str',
        'exposed_height1': 'int',
        'exposed_height2': 'int',
        'exposed_height_combo_tid': 'int',
        'exposed_height_combo_name': 'str',
        'avalanche_ext_tid': 'int',
        'avalanche_ext_name': 'str',
        'aval_cause_tid': 'int',
        'aval_cause_name': 'str',
        'aval_trigger_simple_tid': 'int',
        'aval_trigger_simple_name': 'str',
        'destructive_size_tid': 'int',
        'destructive_size_name': 'str',
        'aval_propagation_tid': 'int',
        'aval_propagation_name': 'str',
        'comment': 'str'
    }

    attribute_map = {
        'estimated_num_tid': 'EstimatedNumTID',
        'estimated_num_name': 'EstimatedNumName',
        'dt_start': 'DtStart',
        'dt_end': 'DtEnd',
        'dt_off_start': 'DtOffStart',
        'dt_off_end': 'DtOffEnd',
        'valid_exposition': 'ValidExposition',
        'exposed_height1': 'ExposedHeight1',
        'exposed_height2': 'ExposedHeight2',
        'exposed_height_combo_tid': 'ExposedHeightComboTID',
        'exposed_height_combo_name': 'ExposedHeightComboName',
        'avalanche_ext_tid': 'AvalancheExtTID',
        'avalanche_ext_name': 'AvalancheExtName',
        'aval_cause_tid': 'AvalCauseTID',
        'aval_cause_name': 'AvalCauseName',
        'aval_trigger_simple_tid': 'AvalTriggerSimpleTID',
        'aval_trigger_simple_name': 'AvalTriggerSimpleName',
        'destructive_size_tid': 'DestructiveSizeTID',
        'destructive_size_name': 'DestructiveSizeName',
        'aval_propagation_tid': 'AvalPropagationTID',
        'aval_propagation_name': 'AvalPropagationName',
        'comment': 'Comment'
    }

    def __init__(self, estimated_num_tid=None, estimated_num_name=None, dt_start=None, dt_end=None, dt_off_start=None, dt_off_end=None, valid_exposition=None, exposed_height1=None, exposed_height2=None, exposed_height_combo_tid=None, exposed_height_combo_name=None, avalanche_ext_tid=None, avalanche_ext_name=None, aval_cause_tid=None, aval_cause_name=None, aval_trigger_simple_tid=None, aval_trigger_simple_name=None, destructive_size_tid=None, destructive_size_name=None, aval_propagation_tid=None, aval_propagation_name=None, comment=None):  # noqa: E501
        """AvalancheActivityObs2ViewModel - a model defined in Swagger"""  # noqa: E501
        self._estimated_num_tid = None
        self._estimated_num_name = None
        self._dt_start = None
        self._dt_end = None
        self._dt_off_start = None
        self._dt_off_end = None
        self._valid_exposition = None
        self._exposed_height1 = None
        self._exposed_height2 = None
        self._exposed_height_combo_tid = None
        self._exposed_height_combo_name = None
        self._avalanche_ext_tid = None
        self._avalanche_ext_name = None
        self._aval_cause_tid = None
        self._aval_cause_name = None
        self._aval_trigger_simple_tid = None
        self._aval_trigger_simple_name = None
        self._destructive_size_tid = None
        self._destructive_size_name = None
        self._aval_propagation_tid = None
        self._aval_propagation_name = None
        self._comment = None
        self.discriminator = None
        if estimated_num_tid is not None:
            self.estimated_num_tid = estimated_num_tid
        if estimated_num_name is not None:
            self.estimated_num_name = estimated_num_name
        if dt_start is not None:
            self.dt_start = dt_start
        if dt_end is not None:
            self.dt_end = dt_end
        if dt_off_start is not None:
            self.dt_off_start = dt_off_start
        if dt_off_end is not None:
            self.dt_off_end = dt_off_end
        if valid_exposition is not None:
            self.valid_exposition = valid_exposition
        if exposed_height1 is not None:
            self.exposed_height1 = exposed_height1
        if exposed_height2 is not None:
            self.exposed_height2 = exposed_height2
        if exposed_height_combo_tid is not None:
            self.exposed_height_combo_tid = exposed_height_combo_tid
        if exposed_height_combo_name is not None:
            self.exposed_height_combo_name = exposed_height_combo_name
        if avalanche_ext_tid is not None:
            self.avalanche_ext_tid = avalanche_ext_tid
        if avalanche_ext_name is not None:
            self.avalanche_ext_name = avalanche_ext_name
        if aval_cause_tid is not None:
            self.aval_cause_tid = aval_cause_tid
        if aval_cause_name is not None:
            self.aval_cause_name = aval_cause_name
        if aval_trigger_simple_tid is not None:
            self.aval_trigger_simple_tid = aval_trigger_simple_tid
        if aval_trigger_simple_name is not None:
            self.aval_trigger_simple_name = aval_trigger_simple_name
        if destructive_size_tid is not None:
            self.destructive_size_tid = destructive_size_tid
        if destructive_size_name is not None:
            self.destructive_size_name = destructive_size_name
        if aval_propagation_tid is not None:
            self.aval_propagation_tid = aval_propagation_tid
        if aval_propagation_name is not None:
            self.aval_propagation_name = aval_propagation_name
        if comment is not None:
            self.comment = comment

    @property
    def estimated_num_tid(self):
        """Gets the estimated_num_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The estimated_num_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._estimated_num_tid

    @estimated_num_tid.setter
    def estimated_num_tid(self, estimated_num_tid):
        """Sets the estimated_num_tid of this AvalancheActivityObs2ViewModel.


        :param estimated_num_tid: The estimated_num_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._estimated_num_tid = estimated_num_tid

    @property
    def estimated_num_name(self):
        """Gets the estimated_num_name of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The estimated_num_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._estimated_num_name

    @estimated_num_name.setter
    def estimated_num_name(self, estimated_num_name):
        """Sets the estimated_num_name of this AvalancheActivityObs2ViewModel.


        :param estimated_num_name: The estimated_num_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._estimated_num_name = estimated_num_name

    @property
    def dt_start(self):
        """Gets the dt_start of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The dt_start of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_start

    @dt_start.setter
    def dt_start(self, dt_start):
        """Sets the dt_start of this AvalancheActivityObs2ViewModel.


        :param dt_start: The dt_start of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_start = dt_start

    @property
    def dt_end(self):
        """Gets the dt_end of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The dt_end of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_end

    @dt_end.setter
    def dt_end(self, dt_end):
        """Sets the dt_end of this AvalancheActivityObs2ViewModel.


        :param dt_end: The dt_end of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_end = dt_end

    @property
    def dt_off_start(self):
        """Gets the dt_off_start of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The dt_off_start of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_off_start

    @dt_off_start.setter
    def dt_off_start(self, dt_off_start):
        """Sets the dt_off_start of this AvalancheActivityObs2ViewModel.


        :param dt_off_start: The dt_off_start of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_off_start = dt_off_start

    @property
    def dt_off_end(self):
        """Gets the dt_off_end of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The dt_off_end of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_off_end

    @dt_off_end.setter
    def dt_off_end(self, dt_off_end):
        """Sets the dt_off_end of this AvalancheActivityObs2ViewModel.


        :param dt_off_end: The dt_off_end of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_off_end = dt_off_end

    @property
    def valid_exposition(self):
        """Gets the valid_exposition of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The valid_exposition of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._valid_exposition

    @valid_exposition.setter
    def valid_exposition(self, valid_exposition):
        """Sets the valid_exposition of this AvalancheActivityObs2ViewModel.


        :param valid_exposition: The valid_exposition of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._valid_exposition = valid_exposition

    @property
    def exposed_height1(self):
        """Gets the exposed_height1 of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The exposed_height1 of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height1

    @exposed_height1.setter
    def exposed_height1(self, exposed_height1):
        """Sets the exposed_height1 of this AvalancheActivityObs2ViewModel.


        :param exposed_height1: The exposed_height1 of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height1 = exposed_height1

    @property
    def exposed_height2(self):
        """Gets the exposed_height2 of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The exposed_height2 of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height2

    @exposed_height2.setter
    def exposed_height2(self, exposed_height2):
        """Sets the exposed_height2 of this AvalancheActivityObs2ViewModel.


        :param exposed_height2: The exposed_height2 of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height2 = exposed_height2

    @property
    def exposed_height_combo_tid(self):
        """Gets the exposed_height_combo_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The exposed_height_combo_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height_combo_tid

    @exposed_height_combo_tid.setter
    def exposed_height_combo_tid(self, exposed_height_combo_tid):
        """Sets the exposed_height_combo_tid of this AvalancheActivityObs2ViewModel.


        :param exposed_height_combo_tid: The exposed_height_combo_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height_combo_tid = exposed_height_combo_tid

    @property
    def exposed_height_combo_name(self):
        """Gets the exposed_height_combo_name of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The exposed_height_combo_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._exposed_height_combo_name

    @exposed_height_combo_name.setter
    def exposed_height_combo_name(self, exposed_height_combo_name):
        """Sets the exposed_height_combo_name of this AvalancheActivityObs2ViewModel.


        :param exposed_height_combo_name: The exposed_height_combo_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._exposed_height_combo_name = exposed_height_combo_name

    @property
    def avalanche_ext_tid(self):
        """Gets the avalanche_ext_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The avalanche_ext_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_ext_tid

    @avalanche_ext_tid.setter
    def avalanche_ext_tid(self, avalanche_ext_tid):
        """Sets the avalanche_ext_tid of this AvalancheActivityObs2ViewModel.


        :param avalanche_ext_tid: The avalanche_ext_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_ext_tid = avalanche_ext_tid

    @property
    def avalanche_ext_name(self):
        """Gets the avalanche_ext_name of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The avalanche_ext_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_ext_name

    @avalanche_ext_name.setter
    def avalanche_ext_name(self, avalanche_ext_name):
        """Sets the avalanche_ext_name of this AvalancheActivityObs2ViewModel.


        :param avalanche_ext_name: The avalanche_ext_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_ext_name = avalanche_ext_name

    @property
    def aval_cause_tid(self):
        """Gets the aval_cause_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The aval_cause_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_tid

    @aval_cause_tid.setter
    def aval_cause_tid(self, aval_cause_tid):
        """Sets the aval_cause_tid of this AvalancheActivityObs2ViewModel.


        :param aval_cause_tid: The aval_cause_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_tid = aval_cause_tid

    @property
    def aval_cause_name(self):
        """Gets the aval_cause_name of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The aval_cause_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_name

    @aval_cause_name.setter
    def aval_cause_name(self, aval_cause_name):
        """Sets the aval_cause_name of this AvalancheActivityObs2ViewModel.


        :param aval_cause_name: The aval_cause_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_name = aval_cause_name

    @property
    def aval_trigger_simple_tid(self):
        """Gets the aval_trigger_simple_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The aval_trigger_simple_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_trigger_simple_tid

    @aval_trigger_simple_tid.setter
    def aval_trigger_simple_tid(self, aval_trigger_simple_tid):
        """Sets the aval_trigger_simple_tid of this AvalancheActivityObs2ViewModel.


        :param aval_trigger_simple_tid: The aval_trigger_simple_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_trigger_simple_tid = aval_trigger_simple_tid

    @property
    def aval_trigger_simple_name(self):
        """Gets the aval_trigger_simple_name of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The aval_trigger_simple_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_trigger_simple_name

    @aval_trigger_simple_name.setter
    def aval_trigger_simple_name(self, aval_trigger_simple_name):
        """Sets the aval_trigger_simple_name of this AvalancheActivityObs2ViewModel.


        :param aval_trigger_simple_name: The aval_trigger_simple_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_trigger_simple_name = aval_trigger_simple_name

    @property
    def destructive_size_tid(self):
        """Gets the destructive_size_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The destructive_size_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._destructive_size_tid

    @destructive_size_tid.setter
    def destructive_size_tid(self, destructive_size_tid):
        """Sets the destructive_size_tid of this AvalancheActivityObs2ViewModel.


        :param destructive_size_tid: The destructive_size_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._destructive_size_tid = destructive_size_tid

    @property
    def destructive_size_name(self):
        """Gets the destructive_size_name of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The destructive_size_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._destructive_size_name

    @destructive_size_name.setter
    def destructive_size_name(self, destructive_size_name):
        """Sets the destructive_size_name of this AvalancheActivityObs2ViewModel.


        :param destructive_size_name: The destructive_size_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._destructive_size_name = destructive_size_name

    @property
    def aval_propagation_tid(self):
        """Gets the aval_propagation_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The aval_propagation_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_propagation_tid

    @aval_propagation_tid.setter
    def aval_propagation_tid(self, aval_propagation_tid):
        """Sets the aval_propagation_tid of this AvalancheActivityObs2ViewModel.


        :param aval_propagation_tid: The aval_propagation_tid of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: int
        """

        self._aval_propagation_tid = aval_propagation_tid

    @property
    def aval_propagation_name(self):
        """Gets the aval_propagation_name of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The aval_propagation_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_propagation_name

    @aval_propagation_name.setter
    def aval_propagation_name(self, aval_propagation_name):
        """Sets the aval_propagation_name of this AvalancheActivityObs2ViewModel.


        :param aval_propagation_name: The aval_propagation_name of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._aval_propagation_name = aval_propagation_name

    @property
    def comment(self):
        """Gets the comment of this AvalancheActivityObs2ViewModel.  # noqa: E501


        :return: The comment of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheActivityObs2ViewModel.


        :param comment: The comment of this AvalancheActivityObs2ViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheActivityObs2ViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheActivityObs2ViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CompressionTestViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compression_test_id': 'int',
        'compression_test_tid': 'int',
        'compression_test_name': 'str',
        'taps_fracture': 'int',
        'taps_full_propagation': 'int',
        'propagation_tid': 'int',
        'propagation_name': 'str',
        'fracture_depth': 'float',
        'stability_eval_tid': 'int',
        'stability_eval_name': 'str',
        'compr_test_fracture_tid': 'int',
        'compr_test_fracture_name': 'str',
        'comment': 'str',
        'include_in_snow_profile': 'bool'
    }

    attribute_map = {
        'compression_test_id': 'CompressionTestID',
        'compression_test_tid': 'CompressionTestTID',
        'compression_test_name': 'CompressionTestName',
        'taps_fracture': 'TapsFracture',
        'taps_full_propagation': 'TapsFullPropagation',
        'propagation_tid': 'PropagationTID',
        'propagation_name': 'PropagationName',
        'fracture_depth': 'FractureDepth',
        'stability_eval_tid': 'StabilityEvalTID',
        'stability_eval_name': 'StabilityEvalName',
        'compr_test_fracture_tid': 'ComprTestFractureTID',
        'compr_test_fracture_name': 'ComprTestFractureName',
        'comment': 'Comment',
        'include_in_snow_profile': 'IncludeInSnowProfile'
    }

    def __init__(self, compression_test_id=None, compression_test_tid=None, compression_test_name=None, taps_fracture=None, taps_full_propagation=None, propagation_tid=None, propagation_name=None, fracture_depth=None, stability_eval_tid=None, stability_eval_name=None, compr_test_fracture_tid=None, compr_test_fracture_name=None, comment=None, include_in_snow_profile=None):  # noqa: E501
        """CompressionTestViewModel - a model defined in Swagger"""  # noqa: E501
        self._compression_test_id = None
        self._compression_test_tid = None
        self._compression_test_name = None
        self._taps_fracture = None
        self._taps_full_propagation = None
        self._propagation_tid = None
        self._propagation_name = None
        self._fracture_depth = None
        self._stability_eval_tid = None
        self._stability_eval_name = None
        self._compr_test_fracture_tid = None
        self._compr_test_fracture_name = None
        self._comment = None
        self._include_in_snow_profile = None
        self.discriminator = None
        if compression_test_id is not None:
            self.compression_test_id = compression_test_id
        if compression_test_tid is not None:
            self.compression_test_tid = compression_test_tid
        if compression_test_name is not None:
            self.compression_test_name = compression_test_name
        if taps_fracture is not None:
            self.taps_fracture = taps_fracture
        if taps_full_propagation is not None:
            self.taps_full_propagation = taps_full_propagation
        if propagation_tid is not None:
            self.propagation_tid = propagation_tid
        if propagation_name is not None:
            self.propagation_name = propagation_name
        if fracture_depth is not None:
            self.fracture_depth = fracture_depth
        if stability_eval_tid is not None:
            self.stability_eval_tid = stability_eval_tid
        if stability_eval_name is not None:
            self.stability_eval_name = stability_eval_name
        if compr_test_fracture_tid is not None:
            self.compr_test_fracture_tid = compr_test_fracture_tid
        if compr_test_fracture_name is not None:
            self.compr_test_fracture_name = compr_test_fracture_name
        if comment is not None:
            self.comment = comment
        if include_in_snow_profile is not None:
            self.include_in_snow_profile = include_in_snow_profile

    @property
    def compression_test_id(self):
        """Gets the compression_test_id of this CompressionTestViewModel.  # noqa: E501


        :return: The compression_test_id of this CompressionTestViewModel.  # noqa: E501
        :rtype: int
        """
        return self._compression_test_id

    @compression_test_id.setter
    def compression_test_id(self, compression_test_id):
        """Sets the compression_test_id of this CompressionTestViewModel.


        :param compression_test_id: The compression_test_id of this CompressionTestViewModel.  # noqa: E501
        :type: int
        """

        self._compression_test_id = compression_test_id

    @property
    def compression_test_tid(self):
        """Gets the compression_test_tid of this CompressionTestViewModel.  # noqa: E501


        :return: The compression_test_tid of this CompressionTestViewModel.  # noqa: E501
        :rtype: int
        """
        return self._compression_test_tid

    @compression_test_tid.setter
    def compression_test_tid(self, compression_test_tid):
        """Sets the compression_test_tid of this CompressionTestViewModel.


        :param compression_test_tid: The compression_test_tid of this CompressionTestViewModel.  # noqa: E501
        :type: int
        """

        self._compression_test_tid = compression_test_tid

    @property
    def compression_test_name(self):
        """Gets the compression_test_name of this CompressionTestViewModel.  # noqa: E501


        :return: The compression_test_name of this CompressionTestViewModel.  # noqa: E501
        :rtype: str
        """
        return self._compression_test_name

    @compression_test_name.setter
    def compression_test_name(self, compression_test_name):
        """Sets the compression_test_name of this CompressionTestViewModel.


        :param compression_test_name: The compression_test_name of this CompressionTestViewModel.  # noqa: E501
        :type: str
        """

        self._compression_test_name = compression_test_name

    @property
    def taps_fracture(self):
        """Gets the taps_fracture of this CompressionTestViewModel.  # noqa: E501


        :return: The taps_fracture of this CompressionTestViewModel.  # noqa: E501
        :rtype: int
        """
        return self._taps_fracture

    @taps_fracture.setter
    def taps_fracture(self, taps_fracture):
        """Sets the taps_fracture of this CompressionTestViewModel.


        :param taps_fracture: The taps_fracture of this CompressionTestViewModel.  # noqa: E501
        :type: int
        """

        self._taps_fracture = taps_fracture

    @property
    def taps_full_propagation(self):
        """Gets the taps_full_propagation of this CompressionTestViewModel.  # noqa: E501


        :return: The taps_full_propagation of this CompressionTestViewModel.  # noqa: E501
        :rtype: int
        """
        return self._taps_full_propagation

    @taps_full_propagation.setter
    def taps_full_propagation(self, taps_full_propagation):
        """Sets the taps_full_propagation of this CompressionTestViewModel.


        :param taps_full_propagation: The taps_full_propagation of this CompressionTestViewModel.  # noqa: E501
        :type: int
        """

        self._taps_full_propagation = taps_full_propagation

    @property
    def propagation_tid(self):
        """Gets the propagation_tid of this CompressionTestViewModel.  # noqa: E501


        :return: The propagation_tid of this CompressionTestViewModel.  # noqa: E501
        :rtype: int
        """
        return self._propagation_tid

    @propagation_tid.setter
    def propagation_tid(self, propagation_tid):
        """Sets the propagation_tid of this CompressionTestViewModel.


        :param propagation_tid: The propagation_tid of this CompressionTestViewModel.  # noqa: E501
        :type: int
        """

        self._propagation_tid = propagation_tid

    @property
    def propagation_name(self):
        """Gets the propagation_name of this CompressionTestViewModel.  # noqa: E501


        :return: The propagation_name of this CompressionTestViewModel.  # noqa: E501
        :rtype: str
        """
        return self._propagation_name

    @propagation_name.setter
    def propagation_name(self, propagation_name):
        """Sets the propagation_name of this CompressionTestViewModel.


        :param propagation_name: The propagation_name of this CompressionTestViewModel.  # noqa: E501
        :type: str
        """

        self._propagation_name = propagation_name

    @property
    def fracture_depth(self):
        """Gets the fracture_depth of this CompressionTestViewModel.  # noqa: E501


        :return: The fracture_depth of this CompressionTestViewModel.  # noqa: E501
        :rtype: float
        """
        return self._fracture_depth

    @fracture_depth.setter
    def fracture_depth(self, fracture_depth):
        """Sets the fracture_depth of this CompressionTestViewModel.


        :param fracture_depth: The fracture_depth of this CompressionTestViewModel.  # noqa: E501
        :type: float
        """

        self._fracture_depth = fracture_depth

    @property
    def stability_eval_tid(self):
        """Gets the stability_eval_tid of this CompressionTestViewModel.  # noqa: E501


        :return: The stability_eval_tid of this CompressionTestViewModel.  # noqa: E501
        :rtype: int
        """
        return self._stability_eval_tid

    @stability_eval_tid.setter
    def stability_eval_tid(self, stability_eval_tid):
        """Sets the stability_eval_tid of this CompressionTestViewModel.


        :param stability_eval_tid: The stability_eval_tid of this CompressionTestViewModel.  # noqa: E501
        :type: int
        """

        self._stability_eval_tid = stability_eval_tid

    @property
    def stability_eval_name(self):
        """Gets the stability_eval_name of this CompressionTestViewModel.  # noqa: E501


        :return: The stability_eval_name of this CompressionTestViewModel.  # noqa: E501
        :rtype: str
        """
        return self._stability_eval_name

    @stability_eval_name.setter
    def stability_eval_name(self, stability_eval_name):
        """Sets the stability_eval_name of this CompressionTestViewModel.


        :param stability_eval_name: The stability_eval_name of this CompressionTestViewModel.  # noqa: E501
        :type: str
        """

        self._stability_eval_name = stability_eval_name

    @property
    def compr_test_fracture_tid(self):
        """Gets the compr_test_fracture_tid of this CompressionTestViewModel.  # noqa: E501


        :return: The compr_test_fracture_tid of this CompressionTestViewModel.  # noqa: E501
        :rtype: int
        """
        return self._compr_test_fracture_tid

    @compr_test_fracture_tid.setter
    def compr_test_fracture_tid(self, compr_test_fracture_tid):
        """Sets the compr_test_fracture_tid of this CompressionTestViewModel.


        :param compr_test_fracture_tid: The compr_test_fracture_tid of this CompressionTestViewModel.  # noqa: E501
        :type: int
        """

        self._compr_test_fracture_tid = compr_test_fracture_tid

    @property
    def compr_test_fracture_name(self):
        """Gets the compr_test_fracture_name of this CompressionTestViewModel.  # noqa: E501


        :return: The compr_test_fracture_name of this CompressionTestViewModel.  # noqa: E501
        :rtype: str
        """
        return self._compr_test_fracture_name

    @compr_test_fracture_name.setter
    def compr_test_fracture_name(self, compr_test_fracture_name):
        """Sets the compr_test_fracture_name of this CompressionTestViewModel.


        :param compr_test_fracture_name: The compr_test_fracture_name of this CompressionTestViewModel.  # noqa: E501
        :type: str
        """

        self._compr_test_fracture_name = compr_test_fracture_name

    @property
    def comment(self):
        """Gets the comment of this CompressionTestViewModel.  # noqa: E501


        :return: The comment of this CompressionTestViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CompressionTestViewModel.


        :param comment: The comment of this CompressionTestViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def include_in_snow_profile(self):
        """Gets the include_in_snow_profile of this CompressionTestViewModel.  # noqa: E501


        :return: The include_in_snow_profile of this CompressionTestViewModel.  # noqa: E501
        :rtype: bool
        """
        return self._include_in_snow_profile

    @include_in_snow_profile.setter
    def include_in_snow_profile(self, include_in_snow_profile):
        """Sets the include_in_snow_profile of this CompressionTestViewModel.


        :param include_in_snow_profile: The include_in_snow_profile of this CompressionTestViewModel.  # noqa: E501
        :type: bool
        """

        self._include_in_snow_profile = include_in_snow_profile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompressionTestViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompressionTestViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AreasDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'country_id': 'int',
        'country_name': 'str',
        'country_description': 'str',
        'sort_order': 'int',
        'forecast_regions': 'object',
        'counties': 'list[CountyDto]'
    }

    attribute_map = {
        'country_id': 'CountryId',
        'country_name': 'CountryName',
        'country_description': 'CountryDescription',
        'sort_order': 'SortOrder',
        'forecast_regions': 'ForecastRegions',
        'counties': 'Counties'
    }

    def __init__(self, country_id=None, country_name=None, country_description=None, sort_order=None, forecast_regions=None, counties=None):  # noqa: E501
        """AreasDto - a model defined in Swagger"""  # noqa: E501
        self._country_id = None
        self._country_name = None
        self._country_description = None
        self._sort_order = None
        self._forecast_regions = None
        self._counties = None
        self.discriminator = None
        if country_id is not None:
            self.country_id = country_id
        if country_name is not None:
            self.country_name = country_name
        if country_description is not None:
            self.country_description = country_description
        if sort_order is not None:
            self.sort_order = sort_order
        if forecast_regions is not None:
            self.forecast_regions = forecast_regions
        if counties is not None:
            self.counties = counties

    @property
    def country_id(self):
        """Gets the country_id of this AreasDto.  # noqa: E501


        :return: The country_id of this AreasDto.  # noqa: E501
        :rtype: int
        """
        return self._country_id

    @country_id.setter
    def country_id(self, country_id):
        """Sets the country_id of this AreasDto.


        :param country_id: The country_id of this AreasDto.  # noqa: E501
        :type: int
        """

        self._country_id = country_id

    @property
    def country_name(self):
        """Gets the country_name of this AreasDto.  # noqa: E501


        :return: The country_name of this AreasDto.  # noqa: E501
        :rtype: str
        """
        return self._country_name

    @country_name.setter
    def country_name(self, country_name):
        """Sets the country_name of this AreasDto.


        :param country_name: The country_name of this AreasDto.  # noqa: E501
        :type: str
        """

        self._country_name = country_name

    @property
    def country_description(self):
        """Gets the country_description of this AreasDto.  # noqa: E501


        :return: The country_description of this AreasDto.  # noqa: E501
        :rtype: str
        """
        return self._country_description

    @country_description.setter
    def country_description(self, country_description):
        """Sets the country_description of this AreasDto.


        :param country_description: The country_description of this AreasDto.  # noqa: E501
        :type: str
        """

        self._country_description = country_description

    @property
    def sort_order(self):
        """Gets the sort_order of this AreasDto.  # noqa: E501


        :return: The sort_order of this AreasDto.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this AreasDto.


        :param sort_order: The sort_order of this AreasDto.  # noqa: E501
        :type: int
        """

        self._sort_order = sort_order

    @property
    def forecast_regions(self):
        """Gets the forecast_regions of this AreasDto.  # noqa: E501


        :return: The forecast_regions of this AreasDto.  # noqa: E501
        :rtype: object
        """
        return self._forecast_regions

    @forecast_regions.setter
    def forecast_regions(self, forecast_regions):
        """Sets the forecast_regions of this AreasDto.


        :param forecast_regions: The forecast_regions of this AreasDto.  # noqa: E501
        :type: object
        """

        self._forecast_regions = forecast_regions

    @property
    def counties(self):
        """Gets the counties of this AreasDto.  # noqa: E501


        :return: The counties of this AreasDto.  # noqa: E501
        :rtype: list[CountyDto]
        """
        return self._counties

    @counties.setter
    def counties(self, counties):
        """Sets the counties of this AreasDto.


        :param counties: The counties of this AreasDto.  # noqa: E501
        :type: list[CountyDto]
        """

        self._counties = counties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AreasDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AreasDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class RegistrationViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reg_id': 'int',
        'geo_hazard_tid': 'int',
        'geo_hazard_name': 'str',
        'lang_key': 'int',
        'dt_obs_time': 'datetime',
        'dt_reg_time': 'datetime',
        'dt_change_time': 'datetime',
        'source_tid': 'int',
        'source_name': 'str',
        'observer': 'ObserverViewModel',
        'obs_location': 'ObsLocationViewModel',
        'attachments': 'list[AttachmentViewModel]',
        'avalanche_activity_obs': 'list[AvalancheActivityObsViewModel]',
        'avalanche_activity_obs2': 'list[AvalancheActivityObs2ViewModel]',
        'avalanche_danger_obs': 'list[AvalancheDangerObsViewModel]',
        'avalanche_eval_problem2': 'list[AvalancheEvalProblem2ViewModel]',
        'avalanche_evaluation3': 'AvalancheEvaluation3ViewModel',
        'avalanche_evaluation': 'AvalancheEvaluationViewModel',
        'avalanche_obs': 'AvalancheObsViewModel',
        'compression_test': 'list[CompressionTestViewModel]',
        'danger_obs': 'list[DangerObsViewModel]',
        'general_observation': 'GeneralObservationViewModel',
        'ice_cover_obs': 'IceCoverViewModel',
        'ice_thickness': 'IceThicknessViewModel',
        'incident': 'IncidentViewModel',
        'snow_profile': 'AttachmentViewModel',
        'land_slide_obs': 'LandslideViewModel',
        'avalanche_eval_problem': 'list[AvalancheEvalProblemViewModel]',
        'snow_cover_obs': 'SnowCoverObsViewModel',
        'snow_profile2': 'SnowProfileViewModel',
        'snow_surface_observation': 'SnowSurfaceViewModel',
        'water_level': 'WaterLevelViewModel',
        'weather_observation': 'WeatherViewModel',
        'water_level2': 'Waterlevel2ViewModel',
        'damage_obs': 'list[DamageObsViewModel]',
        'avalanche_evaluation2': 'AvalancheEvaluation2ViewModel',
        'summaries': 'list[Summary]',
        'attachment_summaries': 'list[Summary]'
    }

    attribute_map = {
        'reg_id': 'RegID',
        'geo_hazard_tid': 'GeoHazardTID',
        'geo_hazard_name': 'GeoHazardName',
        'lang_key': 'LangKey',
        'dt_obs_time': 'DtObsTime',
        'dt_reg_time': 'DtRegTime',
        'dt_change_time': 'DtChangeTime',
        'source_tid': 'SourceTID',
        'source_name': 'SourceName',
        'observer': 'Observer',
        'obs_location': 'ObsLocation',
        'attachments': 'Attachments',
        'avalanche_activity_obs': 'AvalancheActivityObs',
        'avalanche_activity_obs2': 'AvalancheActivityObs2',
        'avalanche_danger_obs': 'AvalancheDangerObs',
        'avalanche_eval_problem2': 'AvalancheEvalProblem2',
        'avalanche_evaluation3': 'AvalancheEvaluation3',
        'avalanche_evaluation': 'AvalancheEvaluation',
        'avalanche_obs': 'AvalancheObs',
        'compression_test': 'CompressionTest',
        'danger_obs': 'DangerObs',
        'general_observation': 'GeneralObservation',
        'ice_cover_obs': 'IceCoverObs',
        'ice_thickness': 'IceThickness',
        'incident': 'Incident',
        'snow_profile': 'SnowProfile',
        'land_slide_obs': 'LandSlideObs',
        'avalanche_eval_problem': 'AvalancheEvalProblem',
        'snow_cover_obs': 'SnowCoverObs',
        'snow_profile2': 'SnowProfile2',
        'snow_surface_observation': 'SnowSurfaceObservation',
        'water_level': 'WaterLevel',
        'weather_observation': 'WeatherObservation',
        'water_level2': 'WaterLevel2',
        'damage_obs': 'DamageObs',
        'avalanche_evaluation2': 'AvalancheEvaluation2',
        'summaries': 'Summaries',
        'attachment_summaries': 'AttachmentSummaries'
    }

    def __init__(self, reg_id=None, geo_hazard_tid=None, geo_hazard_name=None, lang_key=None, dt_obs_time=None, dt_reg_time=None, dt_change_time=None, source_tid=None, source_name=None, observer=None, obs_location=None, attachments=None, avalanche_activity_obs=None, avalanche_activity_obs2=None, avalanche_danger_obs=None, avalanche_eval_problem2=None, avalanche_evaluation3=None, avalanche_evaluation=None, avalanche_obs=None, compression_test=None, danger_obs=None, general_observation=None, ice_cover_obs=None, ice_thickness=None, incident=None, snow_profile=None, land_slide_obs=None, avalanche_eval_problem=None, snow_cover_obs=None, snow_profile2=None, snow_surface_observation=None, water_level=None, weather_observation=None, water_level2=None, damage_obs=None, avalanche_evaluation2=None, summaries=None, attachment_summaries=None):  # noqa: E501
        """RegistrationViewModel - a model defined in Swagger"""  # noqa: E501
        self._reg_id = None
        self._geo_hazard_tid = None
        self._geo_hazard_name = None
        self._lang_key = None
        self._dt_obs_time = None
        self._dt_reg_time = None
        self._dt_change_time = None
        self._source_tid = None
        self._source_name = None
        self._observer = None
        self._obs_location = None
        self._attachments = None
        self._avalanche_activity_obs = None
        self._avalanche_activity_obs2 = None
        self._avalanche_danger_obs = None
        self._avalanche_eval_problem2 = None
        self._avalanche_evaluation3 = None
        self._avalanche_evaluation = None
        self._avalanche_obs = None
        self._compression_test = None
        self._danger_obs = None
        self._general_observation = None
        self._ice_cover_obs = None
        self._ice_thickness = None
        self._incident = None
        self._snow_profile = None
        self._land_slide_obs = None
        self._avalanche_eval_problem = None
        self._snow_cover_obs = None
        self._snow_profile2 = None
        self._snow_surface_observation = None
        self._water_level = None
        self._weather_observation = None
        self._water_level2 = None
        self._damage_obs = None
        self._avalanche_evaluation2 = None
        self._summaries = None
        self._attachment_summaries = None
        self.discriminator = None
        if reg_id is not None:
            self.reg_id = reg_id
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if geo_hazard_name is not None:
            self.geo_hazard_name = geo_hazard_name
        if lang_key is not None:
            self.lang_key = lang_key
        if dt_obs_time is not None:
            self.dt_obs_time = dt_obs_time
        if dt_reg_time is not None:
            self.dt_reg_time = dt_reg_time
        if dt_change_time is not None:
            self.dt_change_time = dt_change_time
        if source_tid is not None:
            self.source_tid = source_tid
        if source_name is not None:
            self.source_name = source_name
        if observer is not None:
            self.observer = observer
        if obs_location is not None:
            self.obs_location = obs_location
        if attachments is not None:
            self.attachments = attachments
        if avalanche_activity_obs is not None:
            self.avalanche_activity_obs = avalanche_activity_obs
        if avalanche_activity_obs2 is not None:
            self.avalanche_activity_obs2 = avalanche_activity_obs2
        if avalanche_danger_obs is not None:
            self.avalanche_danger_obs = avalanche_danger_obs
        if avalanche_eval_problem2 is not None:
            self.avalanche_eval_problem2 = avalanche_eval_problem2
        if avalanche_evaluation3 is not None:
            self.avalanche_evaluation3 = avalanche_evaluation3
        if avalanche_evaluation is not None:
            self.avalanche_evaluation = avalanche_evaluation
        if avalanche_obs is not None:
            self.avalanche_obs = avalanche_obs
        if compression_test is not None:
            self.compression_test = compression_test
        if danger_obs is not None:
            self.danger_obs = danger_obs
        if general_observation is not None:
            self.general_observation = general_observation
        if ice_cover_obs is not None:
            self.ice_cover_obs = ice_cover_obs
        if ice_thickness is not None:
            self.ice_thickness = ice_thickness
        if incident is not None:
            self.incident = incident
        if snow_profile is not None:
            self.snow_profile = snow_profile
        if land_slide_obs is not None:
            self.land_slide_obs = land_slide_obs
        if avalanche_eval_problem is not None:
            self.avalanche_eval_problem = avalanche_eval_problem
        if snow_cover_obs is not None:
            self.snow_cover_obs = snow_cover_obs
        if snow_profile2 is not None:
            self.snow_profile2 = snow_profile2
        if snow_surface_observation is not None:
            self.snow_surface_observation = snow_surface_observation
        if water_level is not None:
            self.water_level = water_level
        if weather_observation is not None:
            self.weather_observation = weather_observation
        if water_level2 is not None:
            self.water_level2 = water_level2
        if damage_obs is not None:
            self.damage_obs = damage_obs
        if avalanche_evaluation2 is not None:
            self.avalanche_evaluation2 = avalanche_evaluation2
        if summaries is not None:
            self.summaries = summaries
        if attachment_summaries is not None:
            self.attachment_summaries = attachment_summaries

    @property
    def reg_id(self):
        """Gets the reg_id of this RegistrationViewModel.  # noqa: E501


        :return: The reg_id of this RegistrationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._reg_id

    @reg_id.setter
    def reg_id(self, reg_id):
        """Sets the reg_id of this RegistrationViewModel.


        :param reg_id: The reg_id of this RegistrationViewModel.  # noqa: E501
        :type: int
        """

        self._reg_id = reg_id

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this RegistrationViewModel.  # noqa: E501


        :return: The geo_hazard_tid of this RegistrationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this RegistrationViewModel.


        :param geo_hazard_tid: The geo_hazard_tid of this RegistrationViewModel.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 10, 20, 30, 40, 50, 60, 70, 100, 110, 200, 999]  # noqa: E501
        if geo_hazard_tid not in allowed_values:
            raise ValueError(
                "Invalid value for `geo_hazard_tid` ({0}), must be one of {1}"  # noqa: E501
                .format(geo_hazard_tid, allowed_values)
            )

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def geo_hazard_name(self):
        """Gets the geo_hazard_name of this RegistrationViewModel.  # noqa: E501


        :return: The geo_hazard_name of this RegistrationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._geo_hazard_name

    @geo_hazard_name.setter
    def geo_hazard_name(self, geo_hazard_name):
        """Sets the geo_hazard_name of this RegistrationViewModel.


        :param geo_hazard_name: The geo_hazard_name of this RegistrationViewModel.  # noqa: E501
        :type: str
        """

        self._geo_hazard_name = geo_hazard_name

    @property
    def lang_key(self):
        """Gets the lang_key of this RegistrationViewModel.  # noqa: E501


        :return: The lang_key of this RegistrationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._lang_key

    @lang_key.setter
    def lang_key(self, lang_key):
        """Sets the lang_key of this RegistrationViewModel.


        :param lang_key: The lang_key of this RegistrationViewModel.  # noqa: E501
        :type: int
        """

        self._lang_key = lang_key

    @property
    def dt_obs_time(self):
        """Gets the dt_obs_time of this RegistrationViewModel.  # noqa: E501


        :return: The dt_obs_time of this RegistrationViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_obs_time

    @dt_obs_time.setter
    def dt_obs_time(self, dt_obs_time):
        """Sets the dt_obs_time of this RegistrationViewModel.


        :param dt_obs_time: The dt_obs_time of this RegistrationViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_obs_time = dt_obs_time

    @property
    def dt_reg_time(self):
        """Gets the dt_reg_time of this RegistrationViewModel.  # noqa: E501


        :return: The dt_reg_time of this RegistrationViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_reg_time

    @dt_reg_time.setter
    def dt_reg_time(self, dt_reg_time):
        """Sets the dt_reg_time of this RegistrationViewModel.


        :param dt_reg_time: The dt_reg_time of this RegistrationViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_reg_time = dt_reg_time

    @property
    def dt_change_time(self):
        """Gets the dt_change_time of this RegistrationViewModel.  # noqa: E501


        :return: The dt_change_time of this RegistrationViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_change_time

    @dt_change_time.setter
    def dt_change_time(self, dt_change_time):
        """Sets the dt_change_time of this RegistrationViewModel.


        :param dt_change_time: The dt_change_time of this RegistrationViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_change_time = dt_change_time

    @property
    def source_tid(self):
        """Gets the source_tid of this RegistrationViewModel.  # noqa: E501


        :return: The source_tid of this RegistrationViewModel.  # noqa: E501
        :rtype: int
        """
        return self._source_tid

    @source_tid.setter
    def source_tid(self, source_tid):
        """Sets the source_tid of this RegistrationViewModel.


        :param source_tid: The source_tid of this RegistrationViewModel.  # noqa: E501
        :type: int
        """

        self._source_tid = source_tid

    @property
    def source_name(self):
        """Gets the source_name of this RegistrationViewModel.  # noqa: E501


        :return: The source_name of this RegistrationViewModel.  # noqa: E501
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """Sets the source_name of this RegistrationViewModel.


        :param source_name: The source_name of this RegistrationViewModel.  # noqa: E501
        :type: str
        """

        self._source_name = source_name

    @property
    def observer(self):
        """Gets the observer of this RegistrationViewModel.  # noqa: E501


        :return: The observer of this RegistrationViewModel.  # noqa: E501
        :rtype: ObserverViewModel
        """
        return self._observer

    @observer.setter
    def observer(self, observer):
        """Sets the observer of this RegistrationViewModel.


        :param observer: The observer of this RegistrationViewModel.  # noqa: E501
        :type: ObserverViewModel
        """

        self._observer = observer

    @property
    def obs_location(self):
        """Gets the obs_location of this RegistrationViewModel.  # noqa: E501


        :return: The obs_location of this RegistrationViewModel.  # noqa: E501
        :rtype: ObsLocationViewModel
        """
        return self._obs_location

    @obs_location.setter
    def obs_location(self, obs_location):
        """Sets the obs_location of this RegistrationViewModel.


        :param obs_location: The obs_location of this RegistrationViewModel.  # noqa: E501
        :type: ObsLocationViewModel
        """

        self._obs_location = obs_location

    @property
    def attachments(self):
        """Gets the attachments of this RegistrationViewModel.  # noqa: E501


        :return: The attachments of this RegistrationViewModel.  # noqa: E501
        :rtype: list[AttachmentViewModel]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this RegistrationViewModel.


        :param attachments: The attachments of this RegistrationViewModel.  # noqa: E501
        :type: list[AttachmentViewModel]
        """

        self._attachments = attachments

    @property
    def avalanche_activity_obs(self):
        """Gets the avalanche_activity_obs of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_activity_obs of this RegistrationViewModel.  # noqa: E501
        :rtype: list[AvalancheActivityObsViewModel]
        """
        return self._avalanche_activity_obs

    @avalanche_activity_obs.setter
    def avalanche_activity_obs(self, avalanche_activity_obs):
        """Sets the avalanche_activity_obs of this RegistrationViewModel.


        :param avalanche_activity_obs: The avalanche_activity_obs of this RegistrationViewModel.  # noqa: E501
        :type: list[AvalancheActivityObsViewModel]
        """

        self._avalanche_activity_obs = avalanche_activity_obs

    @property
    def avalanche_activity_obs2(self):
        """Gets the avalanche_activity_obs2 of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_activity_obs2 of this RegistrationViewModel.  # noqa: E501
        :rtype: list[AvalancheActivityObs2ViewModel]
        """
        return self._avalanche_activity_obs2

    @avalanche_activity_obs2.setter
    def avalanche_activity_obs2(self, avalanche_activity_obs2):
        """Sets the avalanche_activity_obs2 of this RegistrationViewModel.


        :param avalanche_activity_obs2: The avalanche_activity_obs2 of this RegistrationViewModel.  # noqa: E501
        :type: list[AvalancheActivityObs2ViewModel]
        """

        self._avalanche_activity_obs2 = avalanche_activity_obs2

    @property
    def avalanche_danger_obs(self):
        """Gets the avalanche_danger_obs of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_danger_obs of this RegistrationViewModel.  # noqa: E501
        :rtype: list[AvalancheDangerObsViewModel]
        """
        return self._avalanche_danger_obs

    @avalanche_danger_obs.setter
    def avalanche_danger_obs(self, avalanche_danger_obs):
        """Sets the avalanche_danger_obs of this RegistrationViewModel.


        :param avalanche_danger_obs: The avalanche_danger_obs of this RegistrationViewModel.  # noqa: E501
        :type: list[AvalancheDangerObsViewModel]
        """

        self._avalanche_danger_obs = avalanche_danger_obs

    @property
    def avalanche_eval_problem2(self):
        """Gets the avalanche_eval_problem2 of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_eval_problem2 of this RegistrationViewModel.  # noqa: E501
        :rtype: list[AvalancheEvalProblem2ViewModel]
        """
        return self._avalanche_eval_problem2

    @avalanche_eval_problem2.setter
    def avalanche_eval_problem2(self, avalanche_eval_problem2):
        """Sets the avalanche_eval_problem2 of this RegistrationViewModel.


        :param avalanche_eval_problem2: The avalanche_eval_problem2 of this RegistrationViewModel.  # noqa: E501
        :type: list[AvalancheEvalProblem2ViewModel]
        """

        self._avalanche_eval_problem2 = avalanche_eval_problem2

    @property
    def avalanche_evaluation3(self):
        """Gets the avalanche_evaluation3 of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_evaluation3 of this RegistrationViewModel.  # noqa: E501
        :rtype: AvalancheEvaluation3ViewModel
        """
        return self._avalanche_evaluation3

    @avalanche_evaluation3.setter
    def avalanche_evaluation3(self, avalanche_evaluation3):
        """Sets the avalanche_evaluation3 of this RegistrationViewModel.


        :param avalanche_evaluation3: The avalanche_evaluation3 of this RegistrationViewModel.  # noqa: E501
        :type: AvalancheEvaluation3ViewModel
        """

        self._avalanche_evaluation3 = avalanche_evaluation3

    @property
    def avalanche_evaluation(self):
        """Gets the avalanche_evaluation of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_evaluation of this RegistrationViewModel.  # noqa: E501
        :rtype: AvalancheEvaluationViewModel
        """
        return self._avalanche_evaluation

    @avalanche_evaluation.setter
    def avalanche_evaluation(self, avalanche_evaluation):
        """Sets the avalanche_evaluation of this RegistrationViewModel.


        :param avalanche_evaluation: The avalanche_evaluation of this RegistrationViewModel.  # noqa: E501
        :type: AvalancheEvaluationViewModel
        """

        self._avalanche_evaluation = avalanche_evaluation

    @property
    def avalanche_obs(self):
        """Gets the avalanche_obs of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_obs of this RegistrationViewModel.  # noqa: E501
        :rtype: AvalancheObsViewModel
        """
        return self._avalanche_obs

    @avalanche_obs.setter
    def avalanche_obs(self, avalanche_obs):
        """Sets the avalanche_obs of this RegistrationViewModel.


        :param avalanche_obs: The avalanche_obs of this RegistrationViewModel.  # noqa: E501
        :type: AvalancheObsViewModel
        """

        self._avalanche_obs = avalanche_obs

    @property
    def compression_test(self):
        """Gets the compression_test of this RegistrationViewModel.  # noqa: E501


        :return: The compression_test of this RegistrationViewModel.  # noqa: E501
        :rtype: list[CompressionTestViewModel]
        """
        return self._compression_test

    @compression_test.setter
    def compression_test(self, compression_test):
        """Sets the compression_test of this RegistrationViewModel.


        :param compression_test: The compression_test of this RegistrationViewModel.  # noqa: E501
        :type: list[CompressionTestViewModel]
        """

        self._compression_test = compression_test

    @property
    def danger_obs(self):
        """Gets the danger_obs of this RegistrationViewModel.  # noqa: E501


        :return: The danger_obs of this RegistrationViewModel.  # noqa: E501
        :rtype: list[DangerObsViewModel]
        """
        return self._danger_obs

    @danger_obs.setter
    def danger_obs(self, danger_obs):
        """Sets the danger_obs of this RegistrationViewModel.


        :param danger_obs: The danger_obs of this RegistrationViewModel.  # noqa: E501
        :type: list[DangerObsViewModel]
        """

        self._danger_obs = danger_obs

    @property
    def general_observation(self):
        """Gets the general_observation of this RegistrationViewModel.  # noqa: E501


        :return: The general_observation of this RegistrationViewModel.  # noqa: E501
        :rtype: GeneralObservationViewModel
        """
        return self._general_observation

    @general_observation.setter
    def general_observation(self, general_observation):
        """Sets the general_observation of this RegistrationViewModel.


        :param general_observation: The general_observation of this RegistrationViewModel.  # noqa: E501
        :type: GeneralObservationViewModel
        """

        self._general_observation = general_observation

    @property
    def ice_cover_obs(self):
        """Gets the ice_cover_obs of this RegistrationViewModel.  # noqa: E501


        :return: The ice_cover_obs of this RegistrationViewModel.  # noqa: E501
        :rtype: IceCoverViewModel
        """
        return self._ice_cover_obs

    @ice_cover_obs.setter
    def ice_cover_obs(self, ice_cover_obs):
        """Sets the ice_cover_obs of this RegistrationViewModel.


        :param ice_cover_obs: The ice_cover_obs of this RegistrationViewModel.  # noqa: E501
        :type: IceCoverViewModel
        """

        self._ice_cover_obs = ice_cover_obs

    @property
    def ice_thickness(self):
        """Gets the ice_thickness of this RegistrationViewModel.  # noqa: E501


        :return: The ice_thickness of this RegistrationViewModel.  # noqa: E501
        :rtype: IceThicknessViewModel
        """
        return self._ice_thickness

    @ice_thickness.setter
    def ice_thickness(self, ice_thickness):
        """Sets the ice_thickness of this RegistrationViewModel.


        :param ice_thickness: The ice_thickness of this RegistrationViewModel.  # noqa: E501
        :type: IceThicknessViewModel
        """

        self._ice_thickness = ice_thickness

    @property
    def incident(self):
        """Gets the incident of this RegistrationViewModel.  # noqa: E501


        :return: The incident of this RegistrationViewModel.  # noqa: E501
        :rtype: IncidentViewModel
        """
        return self._incident

    @incident.setter
    def incident(self, incident):
        """Sets the incident of this RegistrationViewModel.


        :param incident: The incident of this RegistrationViewModel.  # noqa: E501
        :type: IncidentViewModel
        """

        self._incident = incident

    @property
    def snow_profile(self):
        """Gets the snow_profile of this RegistrationViewModel.  # noqa: E501


        :return: The snow_profile of this RegistrationViewModel.  # noqa: E501
        :rtype: AttachmentViewModel
        """
        return self._snow_profile

    @snow_profile.setter
    def snow_profile(self, snow_profile):
        """Sets the snow_profile of this RegistrationViewModel.


        :param snow_profile: The snow_profile of this RegistrationViewModel.  # noqa: E501
        :type: AttachmentViewModel
        """

        self._snow_profile = snow_profile

    @property
    def land_slide_obs(self):
        """Gets the land_slide_obs of this RegistrationViewModel.  # noqa: E501


        :return: The land_slide_obs of this RegistrationViewModel.  # noqa: E501
        :rtype: LandslideViewModel
        """
        return self._land_slide_obs

    @land_slide_obs.setter
    def land_slide_obs(self, land_slide_obs):
        """Sets the land_slide_obs of this RegistrationViewModel.


        :param land_slide_obs: The land_slide_obs of this RegistrationViewModel.  # noqa: E501
        :type: LandslideViewModel
        """

        self._land_slide_obs = land_slide_obs

    @property
    def avalanche_eval_problem(self):
        """Gets the avalanche_eval_problem of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_eval_problem of this RegistrationViewModel.  # noqa: E501
        :rtype: list[AvalancheEvalProblemViewModel]
        """
        return self._avalanche_eval_problem

    @avalanche_eval_problem.setter
    def avalanche_eval_problem(self, avalanche_eval_problem):
        """Sets the avalanche_eval_problem of this RegistrationViewModel.


        :param avalanche_eval_problem: The avalanche_eval_problem of this RegistrationViewModel.  # noqa: E501
        :type: list[AvalancheEvalProblemViewModel]
        """

        self._avalanche_eval_problem = avalanche_eval_problem

    @property
    def snow_cover_obs(self):
        """Gets the snow_cover_obs of this RegistrationViewModel.  # noqa: E501


        :return: The snow_cover_obs of this RegistrationViewModel.  # noqa: E501
        :rtype: SnowCoverObsViewModel
        """
        return self._snow_cover_obs

    @snow_cover_obs.setter
    def snow_cover_obs(self, snow_cover_obs):
        """Sets the snow_cover_obs of this RegistrationViewModel.


        :param snow_cover_obs: The snow_cover_obs of this RegistrationViewModel.  # noqa: E501
        :type: SnowCoverObsViewModel
        """

        self._snow_cover_obs = snow_cover_obs

    @property
    def snow_profile2(self):
        """Gets the snow_profile2 of this RegistrationViewModel.  # noqa: E501


        :return: The snow_profile2 of this RegistrationViewModel.  # noqa: E501
        :rtype: SnowProfileViewModel
        """
        return self._snow_profile2

    @snow_profile2.setter
    def snow_profile2(self, snow_profile2):
        """Sets the snow_profile2 of this RegistrationViewModel.


        :param snow_profile2: The snow_profile2 of this RegistrationViewModel.  # noqa: E501
        :type: SnowProfileViewModel
        """

        self._snow_profile2 = snow_profile2

    @property
    def snow_surface_observation(self):
        """Gets the snow_surface_observation of this RegistrationViewModel.  # noqa: E501


        :return: The snow_surface_observation of this RegistrationViewModel.  # noqa: E501
        :rtype: SnowSurfaceViewModel
        """
        return self._snow_surface_observation

    @snow_surface_observation.setter
    def snow_surface_observation(self, snow_surface_observation):
        """Sets the snow_surface_observation of this RegistrationViewModel.


        :param snow_surface_observation: The snow_surface_observation of this RegistrationViewModel.  # noqa: E501
        :type: SnowSurfaceViewModel
        """

        self._snow_surface_observation = snow_surface_observation

    @property
    def water_level(self):
        """Gets the water_level of this RegistrationViewModel.  # noqa: E501


        :return: The water_level of this RegistrationViewModel.  # noqa: E501
        :rtype: WaterLevelViewModel
        """
        return self._water_level

    @water_level.setter
    def water_level(self, water_level):
        """Sets the water_level of this RegistrationViewModel.


        :param water_level: The water_level of this RegistrationViewModel.  # noqa: E501
        :type: WaterLevelViewModel
        """

        self._water_level = water_level

    @property
    def weather_observation(self):
        """Gets the weather_observation of this RegistrationViewModel.  # noqa: E501


        :return: The weather_observation of this RegistrationViewModel.  # noqa: E501
        :rtype: WeatherViewModel
        """
        return self._weather_observation

    @weather_observation.setter
    def weather_observation(self, weather_observation):
        """Sets the weather_observation of this RegistrationViewModel.


        :param weather_observation: The weather_observation of this RegistrationViewModel.  # noqa: E501
        :type: WeatherViewModel
        """

        self._weather_observation = weather_observation

    @property
    def water_level2(self):
        """Gets the water_level2 of this RegistrationViewModel.  # noqa: E501


        :return: The water_level2 of this RegistrationViewModel.  # noqa: E501
        :rtype: Waterlevel2ViewModel
        """
        return self._water_level2

    @water_level2.setter
    def water_level2(self, water_level2):
        """Sets the water_level2 of this RegistrationViewModel.


        :param water_level2: The water_level2 of this RegistrationViewModel.  # noqa: E501
        :type: Waterlevel2ViewModel
        """

        self._water_level2 = water_level2

    @property
    def damage_obs(self):
        """Gets the damage_obs of this RegistrationViewModel.  # noqa: E501


        :return: The damage_obs of this RegistrationViewModel.  # noqa: E501
        :rtype: list[DamageObsViewModel]
        """
        return self._damage_obs

    @damage_obs.setter
    def damage_obs(self, damage_obs):
        """Sets the damage_obs of this RegistrationViewModel.


        :param damage_obs: The damage_obs of this RegistrationViewModel.  # noqa: E501
        :type: list[DamageObsViewModel]
        """

        self._damage_obs = damage_obs

    @property
    def avalanche_evaluation2(self):
        """Gets the avalanche_evaluation2 of this RegistrationViewModel.  # noqa: E501


        :return: The avalanche_evaluation2 of this RegistrationViewModel.  # noqa: E501
        :rtype: AvalancheEvaluation2ViewModel
        """
        return self._avalanche_evaluation2

    @avalanche_evaluation2.setter
    def avalanche_evaluation2(self, avalanche_evaluation2):
        """Sets the avalanche_evaluation2 of this RegistrationViewModel.


        :param avalanche_evaluation2: The avalanche_evaluation2 of this RegistrationViewModel.  # noqa: E501
        :type: AvalancheEvaluation2ViewModel
        """

        self._avalanche_evaluation2 = avalanche_evaluation2

    @property
    def summaries(self):
        """Gets the summaries of this RegistrationViewModel.  # noqa: E501


        :return: The summaries of this RegistrationViewModel.  # noqa: E501
        :rtype: list[Summary]
        """
        return self._summaries

    @summaries.setter
    def summaries(self, summaries):
        """Sets the summaries of this RegistrationViewModel.


        :param summaries: The summaries of this RegistrationViewModel.  # noqa: E501
        :type: list[Summary]
        """

        self._summaries = summaries

    @property
    def attachment_summaries(self):
        """Gets the attachment_summaries of this RegistrationViewModel.  # noqa: E501


        :return: The attachment_summaries of this RegistrationViewModel.  # noqa: E501
        :rtype: list[Summary]
        """
        return self._attachment_summaries

    @attachment_summaries.setter
    def attachment_summaries(self, attachment_summaries):
        """Sets the attachment_summaries of this RegistrationViewModel.


        :param attachment_summaries: The attachment_summaries of this RegistrationViewModel.  # noqa: E501
        :type: list[Summary]
        """

        self._attachment_summaries = attachment_summaries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistrationViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistrationViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CreateTripDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'device_guid': 'str',
        'geo_hazard_id': 'int',
        'lat': 'str',
        'lng': 'str',
        'observation_expected_minutes': 'int',
        'observer_guid': 'str',
        'trip_type_id': 'int'
    }

    attribute_map = {
        'comment': 'Comment',
        'device_guid': 'DeviceGuid',
        'geo_hazard_id': 'GeoHazardID',
        'lat': 'Lat',
        'lng': 'Lng',
        'observation_expected_minutes': 'ObservationExpectedMinutes',
        'observer_guid': 'ObserverGuid',
        'trip_type_id': 'TripTypeID'
    }

    def __init__(self, comment=None, device_guid=None, geo_hazard_id=None, lat=None, lng=None, observation_expected_minutes=None, observer_guid=None, trip_type_id=None):  # noqa: E501
        """CreateTripDto - a model defined in Swagger"""  # noqa: E501
        self._comment = None
        self._device_guid = None
        self._geo_hazard_id = None
        self._lat = None
        self._lng = None
        self._observation_expected_minutes = None
        self._observer_guid = None
        self._trip_type_id = None
        self.discriminator = None
        if comment is not None:
            self.comment = comment
        if device_guid is not None:
            self.device_guid = device_guid
        if geo_hazard_id is not None:
            self.geo_hazard_id = geo_hazard_id
        if lat is not None:
            self.lat = lat
        if lng is not None:
            self.lng = lng
        if observation_expected_minutes is not None:
            self.observation_expected_minutes = observation_expected_minutes
        if observer_guid is not None:
            self.observer_guid = observer_guid
        if trip_type_id is not None:
            self.trip_type_id = trip_type_id

    @property
    def comment(self):
        """Gets the comment of this CreateTripDto.  # noqa: E501


        :return: The comment of this CreateTripDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CreateTripDto.


        :param comment: The comment of this CreateTripDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def device_guid(self):
        """Gets the device_guid of this CreateTripDto.  # noqa: E501


        :return: The device_guid of this CreateTripDto.  # noqa: E501
        :rtype: str
        """
        return self._device_guid

    @device_guid.setter
    def device_guid(self, device_guid):
        """Sets the device_guid of this CreateTripDto.


        :param device_guid: The device_guid of this CreateTripDto.  # noqa: E501
        :type: str
        """

        self._device_guid = device_guid

    @property
    def geo_hazard_id(self):
        """Gets the geo_hazard_id of this CreateTripDto.  # noqa: E501


        :return: The geo_hazard_id of this CreateTripDto.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_id

    @geo_hazard_id.setter
    def geo_hazard_id(self, geo_hazard_id):
        """Sets the geo_hazard_id of this CreateTripDto.


        :param geo_hazard_id: The geo_hazard_id of this CreateTripDto.  # noqa: E501
        :type: int
        """

        self._geo_hazard_id = geo_hazard_id

    @property
    def lat(self):
        """Gets the lat of this CreateTripDto.  # noqa: E501


        :return: The lat of this CreateTripDto.  # noqa: E501
        :rtype: str
        """
        return self._lat

    @lat.setter
    def lat(self, lat):
        """Sets the lat of this CreateTripDto.


        :param lat: The lat of this CreateTripDto.  # noqa: E501
        :type: str
        """

        self._lat = lat

    @property
    def lng(self):
        """Gets the lng of this CreateTripDto.  # noqa: E501


        :return: The lng of this CreateTripDto.  # noqa: E501
        :rtype: str
        """
        return self._lng

    @lng.setter
    def lng(self, lng):
        """Sets the lng of this CreateTripDto.


        :param lng: The lng of this CreateTripDto.  # noqa: E501
        :type: str
        """

        self._lng = lng

    @property
    def observation_expected_minutes(self):
        """Gets the observation_expected_minutes of this CreateTripDto.  # noqa: E501


        :return: The observation_expected_minutes of this CreateTripDto.  # noqa: E501
        :rtype: int
        """
        return self._observation_expected_minutes

    @observation_expected_minutes.setter
    def observation_expected_minutes(self, observation_expected_minutes):
        """Sets the observation_expected_minutes of this CreateTripDto.


        :param observation_expected_minutes: The observation_expected_minutes of this CreateTripDto.  # noqa: E501
        :type: int
        """

        self._observation_expected_minutes = observation_expected_minutes

    @property
    def observer_guid(self):
        """Gets the observer_guid of this CreateTripDto.  # noqa: E501


        :return: The observer_guid of this CreateTripDto.  # noqa: E501
        :rtype: str
        """
        return self._observer_guid

    @observer_guid.setter
    def observer_guid(self, observer_guid):
        """Sets the observer_guid of this CreateTripDto.


        :param observer_guid: The observer_guid of this CreateTripDto.  # noqa: E501
        :type: str
        """

        self._observer_guid = observer_guid

    @property
    def trip_type_id(self):
        """Gets the trip_type_id of this CreateTripDto.  # noqa: E501


        :return: The trip_type_id of this CreateTripDto.  # noqa: E501
        :rtype: int
        """
        return self._trip_type_id

    @trip_type_id.setter
    def trip_type_id(self, trip_type_id):
        """Sets the trip_type_id of this CreateTripDto.


        :param trip_type_id: The trip_type_id of this CreateTripDto.  # noqa: E501
        :type: int
        """

        self._trip_type_id = trip_type_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateTripDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTripDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SnowDensityLayerViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'density_profile_layer_id': 'int',
        'depth': 'float',
        'thickness': 'float',
        'density': 'float',
        'usage_flag_tid': 'int',
        'comment': 'str',
        'weight': 'float',
        'water_equivalent': 'float'
    }

    attribute_map = {
        'density_profile_layer_id': 'DensityProfileLayerID',
        'depth': 'Depth',
        'thickness': 'Thickness',
        'density': 'Density',
        'usage_flag_tid': 'UsageFlagTID',
        'comment': 'Comment',
        'weight': 'Weight',
        'water_equivalent': 'WaterEquivalent'
    }

    def __init__(self, density_profile_layer_id=None, depth=None, thickness=None, density=None, usage_flag_tid=None, comment=None, weight=None, water_equivalent=None):  # noqa: E501
        """SnowDensityLayerViewModel - a model defined in Swagger"""  # noqa: E501
        self._density_profile_layer_id = None
        self._depth = None
        self._thickness = None
        self._density = None
        self._usage_flag_tid = None
        self._comment = None
        self._weight = None
        self._water_equivalent = None
        self.discriminator = None
        if density_profile_layer_id is not None:
            self.density_profile_layer_id = density_profile_layer_id
        if depth is not None:
            self.depth = depth
        if thickness is not None:
            self.thickness = thickness
        if density is not None:
            self.density = density
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if comment is not None:
            self.comment = comment
        if weight is not None:
            self.weight = weight
        if water_equivalent is not None:
            self.water_equivalent = water_equivalent

    @property
    def density_profile_layer_id(self):
        """Gets the density_profile_layer_id of this SnowDensityLayerViewModel.  # noqa: E501


        :return: The density_profile_layer_id of this SnowDensityLayerViewModel.  # noqa: E501
        :rtype: int
        """
        return self._density_profile_layer_id

    @density_profile_layer_id.setter
    def density_profile_layer_id(self, density_profile_layer_id):
        """Sets the density_profile_layer_id of this SnowDensityLayerViewModel.


        :param density_profile_layer_id: The density_profile_layer_id of this SnowDensityLayerViewModel.  # noqa: E501
        :type: int
        """

        self._density_profile_layer_id = density_profile_layer_id

    @property
    def depth(self):
        """Gets the depth of this SnowDensityLayerViewModel.  # noqa: E501


        :return: The depth of this SnowDensityLayerViewModel.  # noqa: E501
        :rtype: float
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this SnowDensityLayerViewModel.


        :param depth: The depth of this SnowDensityLayerViewModel.  # noqa: E501
        :type: float
        """

        self._depth = depth

    @property
    def thickness(self):
        """Gets the thickness of this SnowDensityLayerViewModel.  # noqa: E501


        :return: The thickness of this SnowDensityLayerViewModel.  # noqa: E501
        :rtype: float
        """
        return self._thickness

    @thickness.setter
    def thickness(self, thickness):
        """Sets the thickness of this SnowDensityLayerViewModel.


        :param thickness: The thickness of this SnowDensityLayerViewModel.  # noqa: E501
        :type: float
        """

        self._thickness = thickness

    @property
    def density(self):
        """Gets the density of this SnowDensityLayerViewModel.  # noqa: E501


        :return: The density of this SnowDensityLayerViewModel.  # noqa: E501
        :rtype: float
        """
        return self._density

    @density.setter
    def density(self, density):
        """Sets the density of this SnowDensityLayerViewModel.


        :param density: The density of this SnowDensityLayerViewModel.  # noqa: E501
        :type: float
        """

        self._density = density

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this SnowDensityLayerViewModel.  # noqa: E501


        :return: The usage_flag_tid of this SnowDensityLayerViewModel.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this SnowDensityLayerViewModel.


        :param usage_flag_tid: The usage_flag_tid of this SnowDensityLayerViewModel.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def comment(self):
        """Gets the comment of this SnowDensityLayerViewModel.  # noqa: E501


        :return: The comment of this SnowDensityLayerViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SnowDensityLayerViewModel.


        :param comment: The comment of this SnowDensityLayerViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def weight(self):
        """Gets the weight of this SnowDensityLayerViewModel.  # noqa: E501


        :return: The weight of this SnowDensityLayerViewModel.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this SnowDensityLayerViewModel.


        :param weight: The weight of this SnowDensityLayerViewModel.  # noqa: E501
        :type: float
        """

        self._weight = weight

    @property
    def water_equivalent(self):
        """Gets the water_equivalent of this SnowDensityLayerViewModel.  # noqa: E501


        :return: The water_equivalent of this SnowDensityLayerViewModel.  # noqa: E501
        :rtype: float
        """
        return self._water_equivalent

    @water_equivalent.setter
    def water_equivalent(self, water_equivalent):
        """Sets the water_equivalent of this SnowDensityLayerViewModel.


        :param water_equivalent: The water_equivalent of this SnowDensityLayerViewModel.  # noqa: E501
        :type: float
        """

        self._water_equivalent = water_equivalent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnowDensityLayerViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnowDensityLayerViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ObserverViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'observer_guid': 'str',
        'observer_group_id': 'int',
        'observer_group_name': 'str',
        'nick_name': 'str',
        'observer_id': 'int',
        'observer_name': 'str',
        'competence_level_tid': 'int',
        'competence_level_name': 'str'
    }

    attribute_map = {
        'observer_guid': 'ObserverGUID',
        'observer_group_id': 'ObserverGroupID',
        'observer_group_name': 'ObserverGroupName',
        'nick_name': 'NickName',
        'observer_id': 'ObserverID',
        'observer_name': 'ObserverName',
        'competence_level_tid': 'CompetenceLevelTID',
        'competence_level_name': 'CompetenceLevelName'
    }

    def __init__(self, observer_guid=None, observer_group_id=None, observer_group_name=None, nick_name=None, observer_id=None, observer_name=None, competence_level_tid=None, competence_level_name=None):  # noqa: E501
        """ObserverViewModel - a model defined in Swagger"""  # noqa: E501
        self._observer_guid = None
        self._observer_group_id = None
        self._observer_group_name = None
        self._nick_name = None
        self._observer_id = None
        self._observer_name = None
        self._competence_level_tid = None
        self._competence_level_name = None
        self.discriminator = None
        if observer_guid is not None:
            self.observer_guid = observer_guid
        if observer_group_id is not None:
            self.observer_group_id = observer_group_id
        if observer_group_name is not None:
            self.observer_group_name = observer_group_name
        if nick_name is not None:
            self.nick_name = nick_name
        if observer_id is not None:
            self.observer_id = observer_id
        if observer_name is not None:
            self.observer_name = observer_name
        if competence_level_tid is not None:
            self.competence_level_tid = competence_level_tid
        if competence_level_name is not None:
            self.competence_level_name = competence_level_name

    @property
    def observer_guid(self):
        """Gets the observer_guid of this ObserverViewModel.  # noqa: E501


        :return: The observer_guid of this ObserverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._observer_guid

    @observer_guid.setter
    def observer_guid(self, observer_guid):
        """Sets the observer_guid of this ObserverViewModel.


        :param observer_guid: The observer_guid of this ObserverViewModel.  # noqa: E501
        :type: str
        """

        self._observer_guid = observer_guid

    @property
    def observer_group_id(self):
        """Gets the observer_group_id of this ObserverViewModel.  # noqa: E501


        :return: The observer_group_id of this ObserverViewModel.  # noqa: E501
        :rtype: int
        """
        return self._observer_group_id

    @observer_group_id.setter
    def observer_group_id(self, observer_group_id):
        """Sets the observer_group_id of this ObserverViewModel.


        :param observer_group_id: The observer_group_id of this ObserverViewModel.  # noqa: E501
        :type: int
        """

        self._observer_group_id = observer_group_id

    @property
    def observer_group_name(self):
        """Gets the observer_group_name of this ObserverViewModel.  # noqa: E501


        :return: The observer_group_name of this ObserverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._observer_group_name

    @observer_group_name.setter
    def observer_group_name(self, observer_group_name):
        """Sets the observer_group_name of this ObserverViewModel.


        :param observer_group_name: The observer_group_name of this ObserverViewModel.  # noqa: E501
        :type: str
        """

        self._observer_group_name = observer_group_name

    @property
    def nick_name(self):
        """Gets the nick_name of this ObserverViewModel.  # noqa: E501


        :return: The nick_name of this ObserverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._nick_name

    @nick_name.setter
    def nick_name(self, nick_name):
        """Sets the nick_name of this ObserverViewModel.


        :param nick_name: The nick_name of this ObserverViewModel.  # noqa: E501
        :type: str
        """

        self._nick_name = nick_name

    @property
    def observer_id(self):
        """Gets the observer_id of this ObserverViewModel.  # noqa: E501


        :return: The observer_id of this ObserverViewModel.  # noqa: E501
        :rtype: int
        """
        return self._observer_id

    @observer_id.setter
    def observer_id(self, observer_id):
        """Sets the observer_id of this ObserverViewModel.


        :param observer_id: The observer_id of this ObserverViewModel.  # noqa: E501
        :type: int
        """

        self._observer_id = observer_id

    @property
    def observer_name(self):
        """Gets the observer_name of this ObserverViewModel.  # noqa: E501


        :return: The observer_name of this ObserverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._observer_name

    @observer_name.setter
    def observer_name(self, observer_name):
        """Sets the observer_name of this ObserverViewModel.


        :param observer_name: The observer_name of this ObserverViewModel.  # noqa: E501
        :type: str
        """

        self._observer_name = observer_name

    @property
    def competence_level_tid(self):
        """Gets the competence_level_tid of this ObserverViewModel.  # noqa: E501


        :return: The competence_level_tid of this ObserverViewModel.  # noqa: E501
        :rtype: int
        """
        return self._competence_level_tid

    @competence_level_tid.setter
    def competence_level_tid(self, competence_level_tid):
        """Sets the competence_level_tid of this ObserverViewModel.


        :param competence_level_tid: The competence_level_tid of this ObserverViewModel.  # noqa: E501
        :type: int
        """

        self._competence_level_tid = competence_level_tid

    @property
    def competence_level_name(self):
        """Gets the competence_level_name of this ObserverViewModel.  # noqa: E501


        :return: The competence_level_name of this ObserverViewModel.  # noqa: E501
        :rtype: str
        """
        return self._competence_level_name

    @competence_level_name.setter
    def competence_level_name(self, competence_level_name):
        """Sets the competence_level_name of this ObserverViewModel.


        :param competence_level_name: The competence_level_name of this ObserverViewModel.  # noqa: E501
        :type: str
        """

        self._competence_level_name = competence_level_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ObserverViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObserverViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from varsom_regobs_client.api.account_api import AccountApi
from varsom_regobs_client.api.attachment_api import AttachmentApi
from varsom_regobs_client.api.general_obs_api import GeneralObsApi
from varsom_regobs_client.api.geo_code_api import GeoCodeApi
from varsom_regobs_client.api.helptext_api import HelptextApi
from varsom_regobs_client.api.kdv_elements_api import KdvElementsApi
from varsom_regobs_client.api.location_api import LocationApi
from varsom_regobs_client.api.registration_api import RegistrationApi
from varsom_regobs_client.api.search_api import SearchApi
from varsom_regobs_client.api.token_api import TokenApi
from varsom_regobs_client.api.trip_api import TripApi
# import ApiClient
from varsom_regobs_client.api_client import ApiClient
from varsom_regobs_client.configuration import Configuration
# import models into sdk package
from varsom_regobs_client.models.areas_dto import AreasDto
from varsom_regobs_client.models.at_a_glance_view_model import AtAGlanceViewModel
from varsom_regobs_client.models.attachment_view_model import AttachmentViewModel
from varsom_regobs_client.models.avalanche_activity_obs2_dto import AvalancheActivityObs2Dto
from varsom_regobs_client.models.avalanche_activity_obs2_view_model import AvalancheActivityObs2ViewModel
from varsom_regobs_client.models.avalanche_activity_obs_dto import AvalancheActivityObsDto
from varsom_regobs_client.models.avalanche_activity_obs_view_model import AvalancheActivityObsViewModel
from varsom_regobs_client.models.avalanche_danger_obs_dto import AvalancheDangerObsDto
from varsom_regobs_client.models.avalanche_danger_obs_view_model import AvalancheDangerObsViewModel
from varsom_regobs_client.models.avalanche_eval_problem2_dto import AvalancheEvalProblem2Dto
from varsom_regobs_client.models.avalanche_eval_problem2_view_model import AvalancheEvalProblem2ViewModel
from varsom_regobs_client.models.avalanche_eval_problem_view_model import AvalancheEvalProblemViewModel
from varsom_regobs_client.models.avalanche_evaluation2_view_model import AvalancheEvaluation2ViewModel
from varsom_regobs_client.models.avalanche_evaluation3_dto import AvalancheEvaluation3Dto
from varsom_regobs_client.models.avalanche_evaluation3_view_model import AvalancheEvaluation3ViewModel
from varsom_regobs_client.models.avalanche_evaluation_view_model import AvalancheEvaluationViewModel
from varsom_regobs_client.models.avalanche_obs_dto import AvalancheObsDto
from varsom_regobs_client.models.avalanche_obs_view_model import AvalancheObsViewModel
from varsom_regobs_client.models.compression_test_dto import CompressionTestDto
from varsom_regobs_client.models.compression_test_view_model import CompressionTestViewModel
from varsom_regobs_client.models.county_dto import CountyDto
from varsom_regobs_client.models.create_account_request import CreateAccountRequest
from varsom_regobs_client.models.create_registration_request_dto import CreateRegistrationRequestDto
from varsom_regobs_client.models.create_registration_response_dto import CreateRegistrationResponseDto
from varsom_regobs_client.models.create_trip_dto import CreateTripDto
from varsom_regobs_client.models.damage_obs_dto import DamageObsDto
from varsom_regobs_client.models.damage_obs_view_model import DamageObsViewModel
from varsom_regobs_client.models.danger_obs_dto import DangerObsDto
from varsom_regobs_client.models.danger_obs_view_model import DangerObsViewModel
from varsom_regobs_client.models.density_profile_dto import DensityProfileDto
from varsom_regobs_client.models.density_profile_layer_dto import DensityProfileLayerDto
from varsom_regobs_client.models.finish_trip_dto import FinishTripDto
from varsom_regobs_client.models.forecast_region_dto import ForecastRegionDto
from varsom_regobs_client.models.forecast_region_sub_region_dto import ForecastRegionSubRegionDto
from varsom_regobs_client.models.general_observation_edit_model import GeneralObservationEditModel
from varsom_regobs_client.models.general_observation_view_model import GeneralObservationViewModel
from varsom_regobs_client.models.geo_location_info import GeoLocationInfo
from varsom_regobs_client.models.get_token_request_dto import GetTokenRequestDto
from varsom_regobs_client.models.get_token_response_dto import GetTokenResponseDto
from varsom_regobs_client.models.helptext_dto import HelptextDto
from varsom_regobs_client.models.ice_cover_obs_dto import IceCoverObsDto
from varsom_regobs_client.models.ice_cover_view_model import IceCoverViewModel
from varsom_regobs_client.models.ice_thickness_dto import IceThicknessDto
from varsom_regobs_client.models.ice_thickness_layer_dto import IceThicknessLayerDto
from varsom_regobs_client.models.ice_thickness_layer_view_model import IceThicknessLayerViewModel
from varsom_regobs_client.models.ice_thickness_view_model import IceThicknessViewModel
from varsom_regobs_client.models.incident_dto import IncidentDto
from varsom_regobs_client.models.incident_urls_dto import IncidentUrlsDto
from varsom_regobs_client.models.incident_view_model import IncidentViewModel
from varsom_regobs_client.models.kdv_element import KdvElement
from varsom_regobs_client.models.kdv_elements_response_dto import KdvElementsResponseDto
from varsom_regobs_client.models.land_slide_obs_dto import LandSlideObsDto
from varsom_regobs_client.models.landslide_view_model import LandslideViewModel
from varsom_regobs_client.models.lat_lng_object import LatLngObject
from varsom_regobs_client.models.my_page_data import MyPageData
from varsom_regobs_client.models.obs_location_dto import ObsLocationDto
from varsom_regobs_client.models.obs_location_view_model import ObsLocationViewModel
from varsom_regobs_client.models.obs_locations_response_dto_v2 import ObsLocationsResponseDtoV2
from varsom_regobs_client.models.observer_competence_dto import ObserverCompetenceDto
from varsom_regobs_client.models.observer_competence_level_dto import ObserverCompetenceLevelDto
from varsom_regobs_client.models.observer_group_dto import ObserverGroupDto
from varsom_regobs_client.models.observer_response_dto import ObserverResponseDto
from varsom_regobs_client.models.observer_view_model import ObserverViewModel
from varsom_regobs_client.models.picture_request_dto import PictureRequestDto
from varsom_regobs_client.models.position_dto import PositionDto
from varsom_regobs_client.models.reg_obs_generic_value import RegObsGenericValue
from varsom_regobs_client.models.registration_type_criteria_dto import RegistrationTypeCriteriaDto
from varsom_regobs_client.models.registration_type_dto import RegistrationTypeDto
from varsom_regobs_client.models.registration_type_sub_type_dto import RegistrationTypeSubTypeDto
from varsom_regobs_client.models.registration_view_model import RegistrationViewModel
from varsom_regobs_client.models.search_count_response_dto import SearchCountResponseDto
from varsom_regobs_client.models.search_criteria_request_dto import SearchCriteriaRequestDto
from varsom_regobs_client.models.search_side_bar_dto import SearchSideBarDto
from varsom_regobs_client.models.search_side_bar_request_dto import SearchSideBarRequestDto
from varsom_regobs_client.models.snow_cover_obs_dto import SnowCoverObsDto
from varsom_regobs_client.models.snow_cover_obs_view_model import SnowCoverObsViewModel
from varsom_regobs_client.models.snow_density_layer_view_model import SnowDensityLayerViewModel
from varsom_regobs_client.models.snow_density_view_model import SnowDensityViewModel
from varsom_regobs_client.models.snow_profile_dto import SnowProfileDto
from varsom_regobs_client.models.snow_profile_view_model import SnowProfileViewModel
from varsom_regobs_client.models.snow_surface_observation_dto import SnowSurfaceObservationDto
from varsom_regobs_client.models.snow_surface_view_model import SnowSurfaceViewModel
from varsom_regobs_client.models.snow_temp_obs_view_model import SnowTempObsViewModel
from varsom_regobs_client.models.snow_temp_view_model import SnowTempViewModel
from varsom_regobs_client.models.strat_profile_dto import StratProfileDto
from varsom_regobs_client.models.strat_profile_layer_dto import StratProfileLayerDto
from varsom_regobs_client.models.strat_profile_layer_view_model import StratProfileLayerViewModel
from varsom_regobs_client.models.strat_profile_view_model import StratProfileViewModel
from varsom_regobs_client.models.summary import Summary
from varsom_regobs_client.models.temp_obs_dto import TempObsDto
from varsom_regobs_client.models.temp_profile_obs_dto import TempProfileObsDto
from varsom_regobs_client.models.url_view_model import UrlViewModel
from varsom_regobs_client.models.water_level2_dto import WaterLevel2Dto
from varsom_regobs_client.models.water_level_dto import WaterLevelDto
from varsom_regobs_client.models.water_level_measurement_dto import WaterLevelMeasurementDto
from varsom_regobs_client.models.water_level_measurement_view_model import WaterLevelMeasurementViewModel
from varsom_regobs_client.models.water_level_view_model import WaterLevelViewModel
from varsom_regobs_client.models.waterlevel2_view_model import Waterlevel2ViewModel
from varsom_regobs_client.models.weather_observation_dto import WeatherObservationDto
from varsom_regobs_client.models.weather_view_model import WeatherViewModel
from varsom_regobs_client.models.within_extent_criteria_dto import WithinExtentCriteriaDto
from varsom_regobs_client.models.within_radius_criteria_dto import WithinRadiusCriteriaDto



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheEvaluation3Dto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avalanche_danger_tid': 'int',
        'avalanche_evaluation': 'str',
        'avalanche_development': 'str',
        'usage_flag_tid': 'int',
        'forecast_correct_tid': 'int',
        'forecast_comment': 'str'
    }

    attribute_map = {
        'avalanche_danger_tid': 'AvalancheDangerTID',
        'avalanche_evaluation': 'AvalancheEvaluation',
        'avalanche_development': 'AvalancheDevelopment',
        'usage_flag_tid': 'UsageFlagTID',
        'forecast_correct_tid': 'ForecastCorrectTID',
        'forecast_comment': 'ForecastComment'
    }

    def __init__(self, avalanche_danger_tid=None, avalanche_evaluation=None, avalanche_development=None, usage_flag_tid=None, forecast_correct_tid=None, forecast_comment=None):  # noqa: E501
        """AvalancheEvaluation3Dto - a model defined in Swagger"""  # noqa: E501
        self._avalanche_danger_tid = None
        self._avalanche_evaluation = None
        self._avalanche_development = None
        self._usage_flag_tid = None
        self._forecast_correct_tid = None
        self._forecast_comment = None
        self.discriminator = None
        if avalanche_danger_tid is not None:
            self.avalanche_danger_tid = avalanche_danger_tid
        if avalanche_evaluation is not None:
            self.avalanche_evaluation = avalanche_evaluation
        if avalanche_development is not None:
            self.avalanche_development = avalanche_development
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if forecast_correct_tid is not None:
            self.forecast_correct_tid = forecast_correct_tid
        if forecast_comment is not None:
            self.forecast_comment = forecast_comment

    @property
    def avalanche_danger_tid(self):
        """Gets the avalanche_danger_tid of this AvalancheEvaluation3Dto.  # noqa: E501

        Faregrad. The AvalancheDangerKD unique identifier  # noqa: E501

        :return: The avalanche_danger_tid of this AvalancheEvaluation3Dto.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_danger_tid

    @avalanche_danger_tid.setter
    def avalanche_danger_tid(self, avalanche_danger_tid):
        """Sets the avalanche_danger_tid of this AvalancheEvaluation3Dto.

        Faregrad. The AvalancheDangerKD unique identifier  # noqa: E501

        :param avalanche_danger_tid: The avalanche_danger_tid of this AvalancheEvaluation3Dto.  # noqa: E501
        :type: int
        """

        self._avalanche_danger_tid = avalanche_danger_tid

    @property
    def avalanche_evaluation(self):
        """Gets the avalanche_evaluation of this AvalancheEvaluation3Dto.  # noqa: E501

        Her blir Skredfarevurdering skrevet inn. I appen blir “Utstrekning” lagt til som tekst i denne kolonnen  # noqa: E501

        :return: The avalanche_evaluation of this AvalancheEvaluation3Dto.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_evaluation

    @avalanche_evaluation.setter
    def avalanche_evaluation(self, avalanche_evaluation):
        """Sets the avalanche_evaluation of this AvalancheEvaluation3Dto.

        Her blir Skredfarevurdering skrevet inn. I appen blir “Utstrekning” lagt til som tekst i denne kolonnen  # noqa: E501

        :param avalanche_evaluation: The avalanche_evaluation of this AvalancheEvaluation3Dto.  # noqa: E501
        :type: str
        """

        self._avalanche_evaluation = avalanche_evaluation

    @property
    def avalanche_development(self):
        """Gets the avalanche_development of this AvalancheEvaluation3Dto.  # noqa: E501

        Her blir forventet utvikling skrevet inn.  # noqa: E501

        :return: The avalanche_development of this AvalancheEvaluation3Dto.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_development

    @avalanche_development.setter
    def avalanche_development(self, avalanche_development):
        """Sets the avalanche_development of this AvalancheEvaluation3Dto.

        Her blir forventet utvikling skrevet inn.  # noqa: E501

        :param avalanche_development: The avalanche_development of this AvalancheEvaluation3Dto.  # noqa: E501
        :type: str
        """

        self._avalanche_development = avalanche_development

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this AvalancheEvaluation3Dto.  # noqa: E501

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm. The UsageFlagKD unique identifier  # noqa: E501

        :return: The usage_flag_tid of this AvalancheEvaluation3Dto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this AvalancheEvaluation3Dto.

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm. The UsageFlagKD unique identifier  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this AvalancheEvaluation3Dto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def forecast_correct_tid(self):
        """Gets the forecast_correct_tid of this AvalancheEvaluation3Dto.  # noqa: E501

        Felt hvor observatøren kan fortelle de syns varslet stemmer. Valg fra liste gitt i ForecastCorrectKD. The ForecastCorrectKD unique identifier  # noqa: E501

        :return: The forecast_correct_tid of this AvalancheEvaluation3Dto.  # noqa: E501
        :rtype: int
        """
        return self._forecast_correct_tid

    @forecast_correct_tid.setter
    def forecast_correct_tid(self, forecast_correct_tid):
        """Sets the forecast_correct_tid of this AvalancheEvaluation3Dto.

        Felt hvor observatøren kan fortelle de syns varslet stemmer. Valg fra liste gitt i ForecastCorrectKD. The ForecastCorrectKD unique identifier  # noqa: E501

        :param forecast_correct_tid: The forecast_correct_tid of this AvalancheEvaluation3Dto.  # noqa: E501
        :type: int
        """

        self._forecast_correct_tid = forecast_correct_tid

    @property
    def forecast_comment(self):
        """Gets the forecast_comment of this AvalancheEvaluation3Dto.  # noqa: E501

        Kommetarfelt for utdypende kommentar om varslet stemmer eller ikke.  # noqa: E501

        :return: The forecast_comment of this AvalancheEvaluation3Dto.  # noqa: E501
        :rtype: str
        """
        return self._forecast_comment

    @forecast_comment.setter
    def forecast_comment(self, forecast_comment):
        """Sets the forecast_comment of this AvalancheEvaluation3Dto.

        Kommetarfelt for utdypende kommentar om varslet stemmer eller ikke.  # noqa: E501

        :param forecast_comment: The forecast_comment of this AvalancheEvaluation3Dto.  # noqa: E501
        :type: str
        """

        self._forecast_comment = forecast_comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheEvaluation3Dto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheEvaluation3Dto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
